<?php

/**
 * WebService SKYBOTResolver - transforme le nom d'un SSO en ses coordonnees celestes
 *   NameSpace : http://vo.imcce.fr/webservices/skybot/
 *   Method    : skybotresolver
 *   URI       : skybotresolver_query.php?<param>=<valeur>[&]
 *               avec param :
 *                  -ep            -> epoque de la recherche, au format ISO ou jour julien ou date contextuelle anglosaxonne
 *                  -obj ou -name  -> nom ou designation du SSO
 *                  -mime          -> type mime de retour de la reponse: 'votable' (defaut), 'html', 'text'
 *                  -output (-out) -> choix des parametres de sortie: 'basic', 'object' (defaut), 'obs', 'all'
 *                  -loc           -> code UAI de l'observatoire (defaut 500)
 *               Parametre additionnel:
 *                  -from          -> nom ou designation du service appelant transmis dans l'entete SOAP 
 *   Response  : Affiche les coordonnees celestes du SSO a l'epoque demandee, au format XML ou text selon le cas. 
 *               Les parametres affiches dependent de l'option '-output' :
 *                  'object': num, nom, alpha, delta, Mv
 *                  'basic' : 'object' + dRAcos(Dec), dDec, ErrPos, dgeo, dhelio, Flag
 *                  'obs'   : 'basic' + Phase, SolElong
 *                  'all'   : 'obs' + x, y, z, x', y', z', JDRef
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2013, IMCCE
 * @since PHP5
 * @version 2.0
 */

// Client's ID 
$from = 'DemoClient';

// Input parameters
$param = array('epoch'    => 'now',
               'name'     => "io",
               'mime'     => "text",
               'output'   => "basic",
               'observer' => "500");

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 0);

// Namespace et WSDL du service
$namespace = 'http://vo.imcce.fr/webservices/skybot';
$uriwsdl   = $namespace.'/skybot.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($namespace, 'clientID', $header)));  
  // Appel de la methode
  $response = $client->__soapCall('skybotresolver',array($param));
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("Content-Type: text/plain");
    echo "Flag  : ".$response->flag."\n";
    echo "Ticket: ".$response->ticket."\n";
    echo "Result: ";
    $res = explode(';', $response->result);
    $nbr = count($res);
    $key = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$key[$i]],"\n"; };
  }
  else
  {
    header("Content-Type: text/xml");
    echo $response->result."\n";
  }
} 
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
